@@ -28,7 +28,11 @@ from miscnn.processing.subfunctions.abstract_subfunction import Abstract_Subfunc
 #          Subfunction class: Normalization           #
 #-----------------------------------------------------#
 """ A Normalization Subfunction class which normalizes the intensity pixel values of an image using
-    the Z-Score technique (default setting) or through scaling to [0,1].
+    the Z-Score technique (default setting), through scaling to [0,1] or to grayscale [0,255].
+
+Args:
+    mode (string):          Mode which normalization approach should be performed.
+                            Possible modi: "z-score", "minmax" or "grayscale"
 
 Methods:
     __init__                Object creation function
@@ -39,8 +43,8 @@ class Normalization(Abstract_Subfunction):
     #---------------------------------------------#
     #                Initialization               #
     #---------------------------------------------#
-    def __init__(self, z_score=True):
-        self.z_score = z_score
+    def __init__(self, mode="z-score"):
+        self.mode = mode
 
     #---------------------------------------------#
     #                Preprocessing                #
@@ -49,24 +53,32 @@ class Normalization(Abstract_Subfunction):
         # Access image
         image = sample.img_data
         # Perform z-score normalization
-        if self.z_score:
+        if self.mode == "z-score":
             # Compute mean and standard deviation
             mean = np.mean(image)
             std = np.std(image)
             # Scaling
             image_normalized = (image - mean) / std
-        # Perform scaling normalization between [0,1]
-        else:
+        # Perform MinMax normalization between [0,1]
+        elif self.mode == "minmax":
             # Identify minimum and maximum
             max_value = np.max(image)
             min_value = np.min(image)
             # Scaling
             image_normalized = (image - min_value) / (max_value - min_value)
+        elif self.mode == "grayscale":
+            # Identify minimum and maximum
+            max_value = np.max(image)
+            min_value = np.min(image)
+            # Scaling
+            image_scaled = (image - min_value) / (max_value - min_value)
+            image_normalized = np.around(image_scaled * 255, decimals=0)
+        else : raise NameError("Subfunction - Normalization: Unknown modus")
         # Update the sample with the normalized image
         sample.img_data = image_normalized
 
     #---------------------------------------------#
     #               Postprocessing                #
     #---------------------------------------------#
-    def postprocessing(self, prediction):
+    def postprocessing(self, sample, prediction):
         return prediction
